@@ -7,7 +7,7 @@ import html
 import sys
 import difflib 
 
-__version__ = "0.0.16"
+__version__ = "0.0.20"
 __author__ = 'Bas Terwijn'
 
 def highlight_diff(str1, str2):
@@ -107,6 +107,7 @@ class Invocation_Tree:
         self.edges = []
         self.is_highlighted = False
         self.graph = None
+        self.prev_global_tracer = None
         self.ignore_calls = {'Invocation_Tree.__exit__', 'Invocation_Tree.stop_trace'}
 
     def __repr__(self):
@@ -114,10 +115,11 @@ class Invocation_Tree:
 
     def __call__(self, fun, *args, **kwargs):
         try:
-            sys.settrace(self.trace_calls)
+            self.prev_global_tracer = sys.gettrace()
+            sys.settrace(self.global_tracer)
             result = fun(*args, **kwargs)
         finally:
-            sys.settrace(None)
+            sys.settrace(self.prev_global_tracer)
         return result
 
     def value_to_string(self, key, value, use_repr=False):
@@ -255,7 +257,7 @@ class Invocation_Tree:
     def get_graph(self):
         return self.graph
 
-    def trace_calls(self, frame, event, arg):
+    def trace(self, frame, event, arg):
         class_fun_name = get_class_function_name(frame)
         if not class_fun_name in self.ignore_calls:
             if event == 'call':
@@ -270,7 +272,29 @@ class Invocation_Tree:
                 self.output_graph(frame, event)
             elif event == 'line' and self.each_line:
                 self.output_graph(frame, event)
-        return self.trace_calls
+
+    def global_tracer(self, frame, event, arg):
+        """ Global trace function that chains to any previous global tracer so it works in a debugger too. """
+        self.trace(frame, event, arg) # update graph
+        # call previous global tracer if any existed
+        prev_local_tracer = self.prev_global_tracer(frame, event, arg) if self.prev_global_tracer else None
+
+        def local_tracer(frame, event, arg):
+            """ Global trace is for a 'call' event that signals a new frame, it returns a local tracer to 
+            handle other events in that frame. """
+            self.trace(frame, event, arg)
+
+        def local_multiplexer(frame, event, arg):
+            """ Multiplexes between the local tracer and any previous local tracer so it works in a debugger too. """
+            nonlocal prev_local_tracer
+            local_tracer(frame, event, arg) # update graph
+            if prev_local_tracer is not None:
+                # call previous local tracer if any existed and update it
+                prev_local_tracer = prev_local_tracer(frame, event, arg)
+            return local_multiplexer
+
+        return local_multiplexer
+
 
 def blocking(filename='tree.pdf'):
     return Invocation_Tree(filename=filename)
